@@ -19,8 +19,8 @@ function App() {
 
   return (
     <div className="app">
-      <h1>Hello World!</h1>
-      <h4>Data from Backend at { backend_url }: { data.toString() }</h4>
+      <h1>{ data }</h1>
+      <h4>Data from Backend at { backend_url }</h4>
     </div>
   );
 }
